Starting MindRoot
=================

The first time you can specify the admin user and password:

``mindroot -u admin -pw password``

The server defaults to `http://0.0.0.0:8010/ <http://0.0.0.0:8010/>`_ .

You can also set the port by specifying ``-p [port]``

You will need to log in.
